==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/CalloutAnnotationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutAnnotationDescription } from "./CalloutAnnotationDescription";
/**
 * @hidden
 */
export let CalloutAnnotationDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalloutAnnotationDescriptionMetadata extends Base {
        static b(a) {
            if (CalloutAnnotationDescriptionMetadata.a == null) {
                CalloutAnnotationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalloutAnnotationDescriptionMetadata.c(CalloutAnnotationDescriptionMetadata.a);
            }
            if (a.k(CalloutAnnotationDescriptionMetadata.a)) {
                return;
            }
            a.ab(CalloutAnnotationDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("XValueRef", "(w:XValue,wf:XValue)DataRef");
            a.item("YValueRef", "(w:YValue,wf:YValue)DataRef");
            a.item("Text", "String");
            a.item("KeyRef", "(w:Key,wf:Key)DataRef");
            a.item("ContentRef", "(w:Content,wf:Content)DataRef");
            a.item("Series", "ExportedType:Series");
            a.item("FormatLabelRef", "(w:FormatLabel,wf:FormatLabel)MethodRef");
            a.item("TextColor", "Brush");
            a.item("Background", "Brush");
            a.item("Outline", "Brush");
            a.item("LeaderBrush", "Brush");
            a.item("StrokeThickness", "Number:double");
            a.item("BackgroundPaddingLeft", "Number:double");
            a.item("BackgroundPaddingTop", "Number:double");
            a.item("BackgroundPaddingRight", "Number:double");
            a.item("BackgroundPaddingBottom", "Number:double");
            a.item("BackgroundCornerRadius", "Number:double");
        }
        static d(a) {
            CalloutAnnotationDescriptionMetadata.b(a);
            a.ad("CalloutAnnotation", () => new CalloutAnnotationDescription());
            a.ac("CalloutAnnotation", CalloutAnnotationDescriptionMetadata.a);
        }
    }
    CalloutAnnotationDescriptionMetadata.$t = markType(CalloutAnnotationDescriptionMetadata, 'CalloutAnnotationDescriptionMetadata');
    CalloutAnnotationDescriptionMetadata.a = null;
    return CalloutAnnotationDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/CalloutAnnotationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutAnnotationDescription } from "./CalloutAnnotationDescription";
/**
 * @hidden
 */
export let CalloutAnnotationDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalloutAnnotationDescriptionMetadata extends Base {
        static b(a) {
            if (CalloutAnnotationDescriptionMetadata.a == null) {
                CalloutAnnotationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalloutAnnotationDescriptionMetadata.c(CalloutAnnotationDescriptionMetadata.a);
            }
            if (a.k(CalloutAnnotationDescriptionMetadata.a)) {
                return;
            }
            a.ac(CalloutAnnotationDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("XValueRef", "(w:XValue,wf:XValue)DataRef");
            a.item("YValueRef", "(w:YValue,wf:YValue)DataRef");
            a.item("Text", "String");
            a.item("KeyRef", "(w:Key,wf:Key)DataRef");
            a.item("ContentRef", "(w:Content,wf:Content)DataRef");
            a.item("Series", "ExportedType:Series");
            a.item("ItemColor", "Brush");
            a.item("FormatLabelRef", "(w:FormatLabel,wf:FormatLabel)MethodRef");
            a.item("TextColor", "Brush");
            a.item("Background", "Brush");
            a.item("Outline", "Brush");
            a.item("LeaderBrush", "Brush");
            a.item("StrokeThickness", "Number:double");
            a.item("BackgroundPaddingLeft", "Number:double");
            a.item("BackgroundPaddingTop", "Number:double");
            a.item("BackgroundPaddingRight", "Number:double");
            a.item("BackgroundPaddingBottom", "Number:double");
            a.item("BackgroundCornerRadius", "Number:double");
        }
        static d(a) {
            CalloutAnnotationDescriptionMetadata.b(a);
            a.ae("CalloutAnnotation", () => new CalloutAnnotationDescription());
            a.ad("CalloutAnnotation", CalloutAnnotationDescriptionMetadata.a);
        }
    }
    CalloutAnnotationDescriptionMetadata.$t = markType(CalloutAnnotationDescriptionMetadata, 'CalloutAnnotationDescriptionMetadata');
    CalloutAnnotationDescriptionMetadata.a = null;
    return CalloutAnnotationDescriptionMetadata;
})();
